#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'moc-qt-interpreter-events.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "libgui/src/moc-qt-interpreter-events.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'moc-qt-interpreter-events.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_octave__qt_interpreter_events_t {
    QByteArrayData data[76];
    char stringdata0[1338];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__qt_interpreter_events_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__qt_interpreter_events_t qt_meta_stringdata_octave__qt_interpreter_events = {
    {
QT_MOC_LITERAL(0, 0, 29), // "octave::qt_interpreter_events"
QT_MOC_LITERAL(1, 30, 16), // "start_gui_signal"
QT_MOC_LITERAL(2, 47, 0), // ""
QT_MOC_LITERAL(3, 48, 7), // "gui_app"
QT_MOC_LITERAL(4, 56, 16), // "close_gui_signal"
QT_MOC_LITERAL(5, 73, 30), // "copy_image_to_clipboard_signal"
QT_MOC_LITERAL(6, 104, 4), // "file"
QT_MOC_LITERAL(7, 109, 11), // "remove_file"
QT_MOC_LITERAL(8, 121, 19), // "focus_window_signal"
QT_MOC_LITERAL(9, 141, 8), // "win_name"
QT_MOC_LITERAL(10, 150, 16), // "edit_file_signal"
QT_MOC_LITERAL(11, 167, 24), // "directory_changed_signal"
QT_MOC_LITERAL(12, 192, 3), // "dir"
QT_MOC_LITERAL(13, 196, 25), // "update_path_dialog_signal"
QT_MOC_LITERAL(14, 222, 18), // "file_remove_signal"
QT_MOC_LITERAL(15, 241, 8), // "old_name"
QT_MOC_LITERAL(16, 250, 8), // "new_name"
QT_MOC_LITERAL(17, 259, 19), // "file_renamed_signal"
QT_MOC_LITERAL(18, 279, 8), // "load_new"
QT_MOC_LITERAL(19, 288, 34), // "execute_command_in_terminal_s..."
QT_MOC_LITERAL(20, 323, 7), // "command"
QT_MOC_LITERAL(21, 331, 20), // "set_workspace_signal"
QT_MOC_LITERAL(22, 352, 9), // "top_level"
QT_MOC_LITERAL(23, 362, 5), // "debug"
QT_MOC_LITERAL(24, 368, 16), // "symbol_info_list"
QT_MOC_LITERAL(25, 385, 7), // "syminfo"
QT_MOC_LITERAL(26, 393, 22), // "clear_workspace_signal"
QT_MOC_LITERAL(27, 416, 20), // "update_prompt_signal"
QT_MOC_LITERAL(28, 437, 6), // "prompt"
QT_MOC_LITERAL(29, 444, 18), // "set_history_signal"
QT_MOC_LITERAL(30, 463, 4), // "hist"
QT_MOC_LITERAL(31, 468, 21), // "append_history_signal"
QT_MOC_LITERAL(32, 490, 10), // "hist_entry"
QT_MOC_LITERAL(33, 501, 20), // "clear_history_signal"
QT_MOC_LITERAL(34, 522, 21), // "enter_debugger_signal"
QT_MOC_LITERAL(35, 544, 20), // "exit_debugger_signal"
QT_MOC_LITERAL(36, 565, 31), // "update_breakpoint_marker_signal"
QT_MOC_LITERAL(37, 597, 6), // "insert"
QT_MOC_LITERAL(38, 604, 4), // "line"
QT_MOC_LITERAL(39, 609, 4), // "cond"
QT_MOC_LITERAL(40, 614, 30), // "insert_debugger_pointer_signal"
QT_MOC_LITERAL(41, 645, 30), // "delete_debugger_pointer_signal"
QT_MOC_LITERAL(42, 676, 23), // "show_preferences_signal"
QT_MOC_LITERAL(43, 700, 21), // "gui_preference_signal"
QT_MOC_LITERAL(44, 722, 3), // "key"
QT_MOC_LITERAL(45, 726, 5), // "value"
QT_MOC_LITERAL(46, 732, 27), // "show_terminal_window_signal"
QT_MOC_LITERAL(47, 760, 25), // "show_documentation_signal"
QT_MOC_LITERAL(48, 786, 29), // "register_documentation_signal"
QT_MOC_LITERAL(49, 816, 31), // "unregister_documentation_signal"
QT_MOC_LITERAL(50, 848, 24), // "show_file_browser_signal"
QT_MOC_LITERAL(51, 873, 27), // "show_command_history_signal"
QT_MOC_LITERAL(52, 901, 21), // "show_workspace_signal"
QT_MOC_LITERAL(53, 923, 26), // "show_community_news_signal"
QT_MOC_LITERAL(54, 950, 6), // "serial"
QT_MOC_LITERAL(55, 957, 25), // "show_release_notes_signal"
QT_MOC_LITERAL(56, 983, 25), // "interpreter_output_signal"
QT_MOC_LITERAL(57, 1009, 3), // "msg"
QT_MOC_LITERAL(58, 1013, 23), // "new_command_line_signal"
QT_MOC_LITERAL(59, 1037, 24), // "gui_status_update_signal"
QT_MOC_LITERAL(60, 1062, 7), // "feature"
QT_MOC_LITERAL(61, 1070, 6), // "status"
QT_MOC_LITERAL(62, 1077, 23), // "update_gui_lexer_signal"
QT_MOC_LITERAL(63, 1101, 16), // "update_apis_only"
QT_MOC_LITERAL(64, 1118, 20), // "edit_variable_signal"
QT_MOC_LITERAL(65, 1139, 4), // "name"
QT_MOC_LITERAL(66, 1144, 12), // "octave_value"
QT_MOC_LITERAL(67, 1157, 3), // "val"
QT_MOC_LITERAL(68, 1161, 30), // "refresh_variable_editor_signal"
QT_MOC_LITERAL(69, 1192, 23), // "confirm_shutdown_signal"
QT_MOC_LITERAL(70, 1216, 21), // "get_named_icon_signal"
QT_MOC_LITERAL(71, 1238, 16), // "settings_changed"
QT_MOC_LITERAL(72, 1255, 18), // "apply_new_settings"
QT_MOC_LITERAL(73, 1274, 23), // "confirm_shutdown_octave"
QT_MOC_LITERAL(74, 1298, 19), // "get_named_icon_slot"
QT_MOC_LITERAL(75, 1318, 19) // "gui_preference_slot"

    },
    "octave::qt_interpreter_events\0"
    "start_gui_signal\0\0gui_app\0close_gui_signal\0"
    "copy_image_to_clipboard_signal\0file\0"
    "remove_file\0focus_window_signal\0"
    "win_name\0edit_file_signal\0"
    "directory_changed_signal\0dir\0"
    "update_path_dialog_signal\0file_remove_signal\0"
    "old_name\0new_name\0file_renamed_signal\0"
    "load_new\0execute_command_in_terminal_signal\0"
    "command\0set_workspace_signal\0top_level\0"
    "debug\0symbol_info_list\0syminfo\0"
    "clear_workspace_signal\0update_prompt_signal\0"
    "prompt\0set_history_signal\0hist\0"
    "append_history_signal\0hist_entry\0"
    "clear_history_signal\0enter_debugger_signal\0"
    "exit_debugger_signal\0"
    "update_breakpoint_marker_signal\0insert\0"
    "line\0cond\0insert_debugger_pointer_signal\0"
    "delete_debugger_pointer_signal\0"
    "show_preferences_signal\0gui_preference_signal\0"
    "key\0value\0show_terminal_window_signal\0"
    "show_documentation_signal\0"
    "register_documentation_signal\0"
    "unregister_documentation_signal\0"
    "show_file_browser_signal\0"
    "show_command_history_signal\0"
    "show_workspace_signal\0show_community_news_signal\0"
    "serial\0show_release_notes_signal\0"
    "interpreter_output_signal\0msg\0"
    "new_command_line_signal\0"
    "gui_status_update_signal\0feature\0"
    "status\0update_gui_lexer_signal\0"
    "update_apis_only\0edit_variable_signal\0"
    "name\0octave_value\0val\0"
    "refresh_variable_editor_signal\0"
    "confirm_shutdown_signal\0get_named_icon_signal\0"
    "settings_changed\0apply_new_settings\0"
    "confirm_shutdown_octave\0get_named_icon_slot\0"
    "gui_preference_slot"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__qt_interpreter_events[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      46,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      43,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  244,    2, 0x06 /* Public */,
       4,    0,  247,    2, 0x06 /* Public */,
       5,    2,  248,    2, 0x06 /* Public */,
       8,    1,  253,    2, 0x06 /* Public */,
      10,    1,  256,    2, 0x06 /* Public */,
      11,    1,  259,    2, 0x06 /* Public */,
      13,    0,  262,    2, 0x06 /* Public */,
      14,    2,  263,    2, 0x06 /* Public */,
      17,    1,  268,    2, 0x06 /* Public */,
      19,    1,  271,    2, 0x06 /* Public */,
      21,    3,  274,    2, 0x06 /* Public */,
      26,    0,  281,    2, 0x06 /* Public */,
      27,    1,  282,    2, 0x06 /* Public */,
      29,    1,  285,    2, 0x06 /* Public */,
      31,    1,  288,    2, 0x06 /* Public */,
      33,    0,  291,    2, 0x06 /* Public */,
      34,    0,  292,    2, 0x06 /* Public */,
      35,    0,  293,    2, 0x06 /* Public */,
      36,    4,  294,    2, 0x06 /* Public */,
      40,    2,  303,    2, 0x06 /* Public */,
      41,    2,  308,    2, 0x06 /* Public */,
      42,    0,  313,    2, 0x06 /* Public */,
      43,    2,  314,    2, 0x06 /* Public */,
      46,    0,  319,    2, 0x06 /* Public */,
      47,    1,  320,    2, 0x06 /* Public */,
      48,    1,  323,    2, 0x06 /* Public */,
      49,    1,  326,    2, 0x06 /* Public */,
      50,    0,  329,    2, 0x06 /* Public */,
      51,    0,  330,    2, 0x06 /* Public */,
      52,    0,  331,    2, 0x06 /* Public */,
      53,    1,  332,    2, 0x06 /* Public */,
      55,    0,  335,    2, 0x06 /* Public */,
      56,    1,  336,    2, 0x06 /* Public */,
      58,    1,  339,    2, 0x06 /* Public */,
      58,    0,  342,    2, 0x26 /* Public | MethodCloned */,
      59,    2,  343,    2, 0x06 /* Public */,
      62,    1,  348,    2, 0x06 /* Public */,
      64,    2,  351,    2, 0x06 /* Public */,
      68,    0,  356,    2, 0x06 /* Public */,
      69,    0,  357,    2, 0x06 /* Public */,
      70,    1,  358,    2, 0x06 /* Public */,
      71,    1,  361,    2, 0x06 /* Public */,
      72,    0,  364,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      73,    0,  365,    2, 0x0a /* Public */,
      74,    1,  366,    2, 0x0a /* Public */,
      75,    2,  369,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,    6,    7,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, QMetaType::QString,   12,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   15,   16,
    QMetaType::Void, QMetaType::Bool,   18,
    QMetaType::Void, QMetaType::QString,   20,
    QMetaType::Void, QMetaType::Bool, QMetaType::Bool, 0x80000000 | 24,   22,   23,   25,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   28,
    QMetaType::Void, QMetaType::QStringList,   30,
    QMetaType::Void, QMetaType::QString,   32,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool, QMetaType::QString, QMetaType::Int, QMetaType::QString,   37,    6,   38,   39,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    2,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    2,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   44,   45,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   54,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   57,
    QMetaType::Void, QMetaType::QString,   57,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   60,   61,
    QMetaType::Void, QMetaType::Bool,   63,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 66,   65,   67,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   65,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   65,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   44,   45,

       0        // eod
};

void octave::qt_interpreter_events::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        qt_interpreter_events *_t = static_cast<qt_interpreter_events *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->start_gui_signal((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->close_gui_signal(); break;
        case 2: _t->copy_image_to_clipboard_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 3: _t->focus_window_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->edit_file_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->directory_changed_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->update_path_dialog_signal(); break;
        case 7: _t->file_remove_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 8: _t->file_renamed_signal((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->execute_command_in_terminal_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->set_workspace_signal((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< const symbol_info_list(*)>(_a[3]))); break;
        case 11: _t->clear_workspace_signal(); break;
        case 12: _t->update_prompt_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 13: _t->set_history_signal((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 14: _t->append_history_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 15: _t->clear_history_signal(); break;
        case 16: _t->enter_debugger_signal(); break;
        case 17: _t->exit_debugger_signal(); break;
        case 18: _t->update_breakpoint_marker_signal((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4]))); break;
        case 19: _t->insert_debugger_pointer_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 20: _t->delete_debugger_pointer_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 21: _t->show_preferences_signal(); break;
        case 22: _t->gui_preference_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 23: _t->show_terminal_window_signal(); break;
        case 24: _t->show_documentation_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 25: _t->register_documentation_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 26: _t->unregister_documentation_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 27: _t->show_file_browser_signal(); break;
        case 28: _t->show_command_history_signal(); break;
        case 29: _t->show_workspace_signal(); break;
        case 30: _t->show_community_news_signal((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 31: _t->show_release_notes_signal(); break;
        case 32: _t->interpreter_output_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 33: _t->new_command_line_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 34: _t->new_command_line_signal(); break;
        case 35: _t->gui_status_update_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 36: _t->update_gui_lexer_signal((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 37: _t->edit_variable_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const octave_value(*)>(_a[2]))); break;
        case 38: _t->refresh_variable_editor_signal(); break;
        case 39: _t->confirm_shutdown_signal(); break;
        case 40: _t->get_named_icon_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 41: _t->settings_changed((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 42: _t->apply_new_settings(); break;
        case 43: _t->confirm_shutdown_octave(); break;
        case 44: _t->get_named_icon_slot((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 45: _t->gui_preference_slot((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (qt_interpreter_events::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::start_gui_signal)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::close_gui_signal)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(const QString & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::copy_image_to_clipboard_signal)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::focus_window_signal)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::edit_file_signal)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::directory_changed_signal)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::update_path_dialog_signal)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::file_remove_signal)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::file_renamed_signal)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::execute_command_in_terminal_signal)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(bool , bool , const symbol_info_list & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::set_workspace_signal)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::clear_workspace_signal)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::update_prompt_signal)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(const QStringList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::set_history_signal)) {
                *result = 13;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::append_history_signal)) {
                *result = 14;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::clear_history_signal)) {
                *result = 15;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::enter_debugger_signal)) {
                *result = 16;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::exit_debugger_signal)) {
                *result = 17;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(bool , const QString & , int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::update_breakpoint_marker_signal)) {
                *result = 18;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(const QString & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::insert_debugger_pointer_signal)) {
                *result = 19;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(const QString & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::delete_debugger_pointer_signal)) {
                *result = 20;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::show_preferences_signal)) {
                *result = 21;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::gui_preference_signal)) {
                *result = 22;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::show_terminal_window_signal)) {
                *result = 23;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::show_documentation_signal)) {
                *result = 24;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::register_documentation_signal)) {
                *result = 25;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::unregister_documentation_signal)) {
                *result = 26;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::show_file_browser_signal)) {
                *result = 27;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::show_command_history_signal)) {
                *result = 28;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::show_workspace_signal)) {
                *result = 29;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::show_community_news_signal)) {
                *result = 30;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::show_release_notes_signal)) {
                *result = 31;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::interpreter_output_signal)) {
                *result = 32;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::new_command_line_signal)) {
                *result = 33;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::gui_status_update_signal)) {
                *result = 35;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::update_gui_lexer_signal)) {
                *result = 36;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(const QString & , const octave_value & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::edit_variable_signal)) {
                *result = 37;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::refresh_variable_editor_signal)) {
                *result = 38;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::confirm_shutdown_signal)) {
                *result = 39;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::get_named_icon_signal)) {
                *result = 40;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::settings_changed)) {
                *result = 41;
                return;
            }
        }
        {
            typedef void (qt_interpreter_events::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&qt_interpreter_events::apply_new_settings)) {
                *result = 42;
                return;
            }
        }
    }
}

const QMetaObject octave::qt_interpreter_events::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_octave__qt_interpreter_events.data,
      qt_meta_data_octave__qt_interpreter_events,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::qt_interpreter_events::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::qt_interpreter_events::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__qt_interpreter_events.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "interpreter_events"))
        return static_cast< interpreter_events*>(this);
    return QObject::qt_metacast(_clname);
}

int octave::qt_interpreter_events::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 46)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 46;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 46)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 46;
    }
    return _id;
}

// SIGNAL 0
void octave::qt_interpreter_events::start_gui_signal(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void octave::qt_interpreter_events::close_gui_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void octave::qt_interpreter_events::copy_image_to_clipboard_signal(const QString & _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void octave::qt_interpreter_events::focus_window_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void octave::qt_interpreter_events::edit_file_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void octave::qt_interpreter_events::directory_changed_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void octave::qt_interpreter_events::update_path_dialog_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void octave::qt_interpreter_events::file_remove_signal(const QString & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void octave::qt_interpreter_events::file_renamed_signal(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void octave::qt_interpreter_events::execute_command_in_terminal_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void octave::qt_interpreter_events::set_workspace_signal(bool _t1, bool _t2, const symbol_info_list & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void octave::qt_interpreter_events::clear_workspace_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void octave::qt_interpreter_events::update_prompt_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void octave::qt_interpreter_events::set_history_signal(const QStringList & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void octave::qt_interpreter_events::append_history_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void octave::qt_interpreter_events::clear_history_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void octave::qt_interpreter_events::enter_debugger_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void octave::qt_interpreter_events::exit_debugger_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void octave::qt_interpreter_events::update_breakpoint_marker_signal(bool _t1, const QString & _t2, int _t3, const QString & _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}

// SIGNAL 19
void octave::qt_interpreter_events::insert_debugger_pointer_signal(const QString & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 19, _a);
}

// SIGNAL 20
void octave::qt_interpreter_events::delete_debugger_pointer_signal(const QString & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 20, _a);
}

// SIGNAL 21
void octave::qt_interpreter_events::show_preferences_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void octave::qt_interpreter_events::gui_preference_signal(const QString & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 22, _a);
}

// SIGNAL 23
void octave::qt_interpreter_events::show_terminal_window_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void octave::qt_interpreter_events::show_documentation_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 24, _a);
}

// SIGNAL 25
void octave::qt_interpreter_events::register_documentation_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 25, _a);
}

// SIGNAL 26
void octave::qt_interpreter_events::unregister_documentation_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 26, _a);
}

// SIGNAL 27
void octave::qt_interpreter_events::show_file_browser_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void octave::qt_interpreter_events::show_command_history_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void octave::qt_interpreter_events::show_workspace_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void octave::qt_interpreter_events::show_community_news_signal(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 30, _a);
}

// SIGNAL 31
void octave::qt_interpreter_events::show_release_notes_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void octave::qt_interpreter_events::interpreter_output_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 32, _a);
}

// SIGNAL 33
void octave::qt_interpreter_events::new_command_line_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 33, _a);
}

// SIGNAL 35
void octave::qt_interpreter_events::gui_status_update_signal(const QString & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 35, _a);
}

// SIGNAL 36
void octave::qt_interpreter_events::update_gui_lexer_signal(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 36, _a);
}

// SIGNAL 37
void octave::qt_interpreter_events::edit_variable_signal(const QString & _t1, const octave_value & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 37, _a);
}

// SIGNAL 38
void octave::qt_interpreter_events::refresh_variable_editor_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 38, nullptr);
}

// SIGNAL 39
void octave::qt_interpreter_events::confirm_shutdown_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 39, nullptr);
}

// SIGNAL 40
void octave::qt_interpreter_events::get_named_icon_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 40, _a);
}

// SIGNAL 41
void octave::qt_interpreter_events::settings_changed(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 41, _a);
}

// SIGNAL 42
void octave::qt_interpreter_events::apply_new_settings()
{
    QMetaObject::activate(this, &staticMetaObject, 42, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
